@@ -9,7 +9,7 @@ RT::Extension::Nagios - Merge and resolve Nagios tickets
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 1;
 
@@ -28,7 +28,7 @@ extension helps you merge and resolve them.
 We identify email by its subject, so please keep it as the
 default one or alike, i.e. subject should pass the regex:
 
-C<<< qr{(PROBLEM|RECOVERY)\s+(Service|Host) Alert: ([^/]+)/(.+)\s+is\s+(\w+)}i >>>
+C<<< qr{(PROBLEM|RECOVERY|ACKNOWLEDGEMENT)\s+(Service|Host) Alert: ([^/]+)/?(.*)\s+is\s+(\w+)}i >>>
 
 e.g.  "PROBLEM Service Alert: localhost/Root Partition is WARNING":
 
@@ -52,13 +52,21 @@ into the new ticket, if $type is 'RECOVERY', resolve the new created ticket.
 if C<< RT->Config->Get('NagiosMergeTickets') >>> is false and $type is
 'RECOVERY', resolve all the found tickets and the new created ticket.
 
+NOTE:
+
+config items like C<NagiosSearchAllQueues> and C<NagiosMergeTickets> can be set
+in etc/RT_SiteConfig.pm like this:
+
+    Set($NagiosSearchAllQueues, 1); # true
+    Set($NagiosMergeTickets, 0); # false
+
 =head1 AUTHOR
 
 sunnavy  C<< <sunnavy@bestpractical.com> >>
 
 =head1 LICENCE AND COPYRIGHT
 
-RT-Extension-Nagios is Copyright 2009 Best Practical Solutions, LLC.
+RT-Extension-Nagios is Copyright 2009-2011 Best Practical Solutions, LLC.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
